@@ -194,17 +194,41 @@ QAction* MuonInstallerMainWindow::getAction(const QString& name)
     return actionCollection()->action(name);
 }
 
+void MuonInstallerMainWindow::openMimeType(const QString& mime)
+{
+    m_view->rootObject()->setProperty("defaultStartup", false);
+    m_mimeToBeOpened = mime;
+    triggerOpenApplication();
+}
+
 void MuonInstallerMainWindow::openApplication(const QString& app)
 {
+    m_view->rootObject()->setProperty("defaultStartup", false);
     m_appToBeOpened = app;
     triggerOpenApplication();
 }
 
+void MuonInstallerMainWindow::openCategory(const QString& category)
+{
+    m_view->rootObject()->setProperty("defaultStartup", false);
+    m_categoryToBeOpened = category;
+    triggerOpenApplication();
+}
+
 void MuonInstallerMainWindow::triggerOpenApplication()
 {
-    if(!m_appToBeOpened.isEmpty() && m_view->rootObject()->property("state").toString()!="loading") {
-        emit openApplicationInternal(m_appToBeOpened);
-        m_appToBeOpened.clear();
+    if(m_view->rootObject()->property("state").toString()!="loading") {
+        if(!m_appToBeOpened.isEmpty()) {
+            emit openApplicationInternal(m_appToBeOpened);
+            m_appToBeOpened.clear();
+        } else if(!m_mimeToBeOpened.isEmpty()) {
+            emit listMimeInternal(m_mimeToBeOpened);
+            m_mimeToBeOpened.clear();
+        } else if(!m_categoryToBeOpened.isEmpty()) {
+            Category* c = new Category(m_categoryToBeOpened, this);
+            emit listCategoryInternal(c);
+            m_mimeToBeOpened.clear();
+        }
     }
 }
 
