@@ -25,6 +25,7 @@
 #include <LibQApt/Globals>
 #include <MuonMainWindow.h>
 
+class Category;
 class QDeclarativeView;
 class ApplicationBackend;
 namespace QApt { class Backend; }
@@ -47,6 +48,8 @@ class MuonInstallerMainWindow : public MuonMainWindow
         void setBackend(QApt::Backend* b);
         void openApplication(const QString& app);
         QUrl featuredSource() const;
+        void openMimeType(const QString& mime);
+        void openCategory(const QString& category);
 
     private slots:
         void triggerOpenApplication();
@@ -54,9 +57,13 @@ class MuonInstallerMainWindow : public MuonMainWindow
     signals:
         void appBackendChanged();
         void openApplicationInternal(const QString& appname);
+        void listMimeInternal(const QString& mime);
+        void listCategoryInternal(Category* c);
 
     private:
         QString m_appToBeOpened;
+        QString m_mimeToBeOpened;
+        QString m_categoryToBeOpened;
         QDeclarativeView* m_view;
 };
 
