@@ -71,9 +71,15 @@ Application::Application(QApt::Package *package, QApt::Backend *backend)
         , m_usageCount(-1)
 {
     m_packageName = m_package->latin1Name().latin1();
-    if (!m_package->controlField(QLatin1String("Appname")).isEmpty()) {
-        m_isExtrasApp = true;
-        m_isTechnical = false;
+    
+    if (m_package->architecture() != m_backend->nativeArchitecture())
+        m_packageName.append(QByteArray(":") + m_package->architecture().toLatin1());
+
+    if (m_package->origin() == QLatin1String("LP-PPA-app-review-board")) {
+        if (!m_package->controlField(QLatin1String("Appname")).isEmpty()) {
+            m_isExtrasApp = true;
+            m_isTechnical = false;
+        }
     }
 }
 
